@@ -22,15 +22,19 @@ class CMonitorFrameScheduler {
     void                    onFrame();
 
   private:
-    bool            canRender();
-    void            onFinishRender();
-    bool            newSchedulingEnabled();
+    bool                       canRender();
+    void                       onFinishRender();
+    bool                       newSchedulingEnabled();
 
-    bool            m_renderAtFrame = true;
-    bool            m_pendingThird  = false;
-    hrc::time_point m_lastRenderBegun;
+    bool                       m_renderAtFrame = true;
+    bool                       m_pendingThird  = false;
+    hrc::time_point            m_lastRenderBegun;
 
-    PHLMONITORREF   m_monitor;
+    PHLMONITORREF              m_monitor;
 
-    UP<CEGLSync>    m_sync;
+    UP<CEGLSync>               m_sync;
+
+    WP<CMonitorFrameScheduler> m_self;
+
+    friend class CMonitor;
 };
